package cn.iocoder.yudao.module.order.controller.admin.batchOrderFeeApply;

import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.order.vo.order.OrderBackVO;
import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.annotations.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;
import cn.iocoder.yudao.framework.excel.util.ExcelUtils;
import cn.iocoder.yudao.framework.operatelog.core.annotations.OperateLog;
import static cn.iocoder.yudao.framework.operatelog.core.enums.OperateTypeEnum.*;
import cn.iocoder.yudao.module.order.vo.batchOrderFeeApply.*;
import cn.iocoder.yudao.module.order.dal.dataobject.batchOrderFeeApply.BatchOrderFeeApplyDO;
import cn.iocoder.yudao.module.order.convert.batchOrderFeeApply.BatchOrderFeeApplyConvert;
import cn.iocoder.yudao.module.order.service.batchOrderFeeApply.BatchOrderFeeApplyService;

@Validated
@RestController
@Api(tags = "管理后台 - 批量订单费用申请")
@RequestMapping("/ecw/batch-order-fee-apply")
public class BatchOrderFeeApplyController {

    @Resource
    private BatchOrderFeeApplyService batchOrderFeeApplyService;

    @PostMapping("/create")
    @ApiOperation("创建批量订单费用申请")
    @PreAuthorize("@ss.hasPermission('ecw:batch-order-fee-apply:create')")
    public CommonResult<Long> createBatchOrderFeeApply(@Valid @RequestBody BatchOrderFeeApplyCreateReqVO createReqVO) {
        return success(batchOrderFeeApplyService.createBatchOrderFeeApply(createReqVO));
    }


    @PostMapping("/getOrderListByIds")
    @ApiOperation("批量获取需要申请费用的订单详情")
    @ApiImplicitParam(name = "orderIds", value = "订单ids", required = true, example = "1024,2048,3072,4096", dataTypeClass = List.class)
    @PreAuthorize("@ss.hasPermission('ecw:batch-order-fee-apply:query')")
    public CommonResult<List<OrderBackVO>> getOrderListByIds(List<Long> orderIds) {
        return success(batchOrderFeeApplyService.getOrderListByIds(orderIds));
    }


    @GetMapping("/info")
    @ApiOperation("获得批量订单费用申请详情")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:batch-order-fee-apply:query')")
    public CommonResult<BatchOrderFeeApplyBackVO> info(@RequestParam("id") Long id) {
        return success(batchOrderFeeApplyService.getBatchOrderFeeApply(id));
    }

    @GetMapping("/getInfoByFormId")
    @ApiOperation("根据流程实例id获得批量订单费用申请详情")
    @ApiImplicitParam(name = "formId", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    @PreAuthorize("@ss.hasPermission('ecw:batch-order-fee-apply:query')")
    public CommonResult<BatchOrderFeeApplyBackVO> getInfoByFormId(@RequestParam("formId") Long formId) {
        return success(batchOrderFeeApplyService.getInfoByFormId(formId));
    }

    @GetMapping("/page")
    @ApiOperation("获得批量订单费用申请分页")
    @PreAuthorize("@ss.hasPermission('ecw:batch-order-fee-apply:query')")
    public CommonResult<PageResult<BatchOrderFeeApplyBackVO>> getBatchOrderFeeApplyPage(@Valid BatchOrderFeeApplyQueryVO query, PageVO page) {
        PageResult<BatchOrderFeeApplyDO> pageResult = batchOrderFeeApplyService.getBatchOrderFeeApplyPage(query, page);
        return success(BatchOrderFeeApplyConvert.INSTANCE.convertPage(pageResult));
    }

}
